@@ -2,19 +2,6 @@ require 'spec_helper'
 
 describe 'swift::containerreconciler' do
 
-  let :default_params do
-    { :manage_service    => true,
-      :enabled           => true,
-      :package_ensure    => 'present',
-      :pipeline          => ['catch_errors', 'proxy-logging', 'proxy-server'],
-      :interval          => '<SERVICE DEFAULT>',
-      :reclaim_age       => '<SERVICE DEFAULT>',
-      :request_tries     => '<SERVICE DEFAULT>',
-      :memcache_servers  => ['127.0.0.1:11211'],
-      :cache_tls_enabled => false,
-    }
-  end
-
   let :params do
     {}
   end
@@ -24,26 +11,46 @@ describe 'swift::containerreconciler' do
   end
 
   shared_examples 'swift::container::reconciler' do
-    let (:p) { default_params.merge!(params) }
-
     context 'with defaults' do
       it 'configures container-reconciler.conf' do
         is_expected.to contain_swift_container_reconciler_config(
-          'pipeline:main/pipeline').with_value(p[:pipeline].join(' '))
+          'pipeline:main/pipeline').with_value('catch_errors proxy-logging cache proxy-server')
         is_expected.to contain_swift_container_reconciler_config(
-          'container-reconciler/interval').with_value(p[:interval])
+          'container-reconciler/interval').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_reconciler_config(
-          'container-reconciler/reclaim_age').with_value(p[:reclaim_age])
+          'container-reconciler/concurrency').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_swift_container_reconciler_config(
-          'container-reconciler/request_tries').with_value(p[:request_tries])
+          'container-reconciler/process').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/processes').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/reclaim_age').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/request_tries').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/log_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/log_level').with_value('INFO')
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/log_facility').with_value('LOG_LOCAL2')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/memcache_servers').with_value('127.0.0.1:11211')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_enabled').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_cafile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_keyfile').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures container-reconciler service' do
         is_expected.to contain_service('swift-container-reconciler').with(
-          :ensure   => (p[:manage_service] && p[:enabled]) ? 'running' : 'stopped',
+          :ensure   => 'running',
           :name     => platform_params[:service_name],
           :provider => platform_params[:service_provider],
-          :enable   => p[:enabled]
+          :enable   => true,
         )
       end
     end
@@ -56,32 +63,39 @@ describe 'swift::containerreconciler' do
           :request_tries => '3',
         )
       end
+
+      it 'configures container-reconciler.conf' do
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/interval').with_value(600)
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/reclaim_age').with_value(10000)
+        is_expected.to contain_swift_container_reconciler_config(
+          'container-reconciler/request_tries').with_value(3)
+      end
     end
 
-    context 'when including cache in pipeline' do
+    context 'when chache is not included in pipeline' do
       before do
         params.merge!(
-          :pipeline         => ['catch_errors', 'proxy-logging', 'cache', 'proxy-server'],
-          :memcache_servers => ['127.0.0.1:11211'],
+          :pipeline => ['catch_errors', 'proxy-logging', 'proxy-server'],
         )
       end
 
-      it 'configures memcache servers' do
+      it 'should not configure memcache servers' do
         is_expected.to contain_swift_container_reconciler_config(
-          'filter:cache/memcache_servers').with_value(p[:memcache_servers])
+          'pipeline:main/pipeline').with_value('catch_errors proxy-logging proxy-server')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/memcache_servers').with_ensure('absent')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_enabled').with_ensure('absent')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_cafile').with_ensure('absent')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_certfile').with_ensure('absent')
+        is_expected.to contain_swift_container_reconciler_config(
+          'filter:cache/tls_keyfile').with_ensure('absent')
       end
     end
-
-    context 'when using swiftinit service provider' do
-      before do
-        params.merge!({ :service_provider => 'swiftinit' })
-      end
-
-      before do
-        platform_params.merge!({ :service_provider => 'swiftinit' })
-      end
-    end
-
   end
 
   on_supported_os({
@@ -95,11 +109,9 @@ describe 'swift::containerreconciler' do
       let(:platform_params) do
         case facts[:os]['family']
         when 'Debian'
-          { :service_name     => 'swift-container-reconciler',
-            :service_provider => nil }
+          { :service_name => 'swift-container-reconciler' }
         when 'RedHat'
-          { :service_name     => 'openstack-swift-container-reconciler',
-            :service_provider => nil }
+          { :service_name => 'openstack-swift-container-reconciler' }
         end
       end
 
